@@ -17,32 +17,57 @@
 struct CHSRspInfoField
 {
     /// 
-    HSErrorID					  ErrorID;
+    HSErrorID                     ErrorID;
     /// ʾ
-    HSErrorMsg					  ErrorMsg;
+    HSErrorMsg                    ErrorMsg;
 };
 
 
 ///֤
 struct CHSReqAuthenticateField
 {
-	/// ˺
-	HSAccountID                   AccountID;
-	/// 
-	HSPassword                    Password;
-	/// ͻid
-	HSAppID                       AppID;
-	/// ֤
-	HSAuthCode                    AuthCode;
+    /// ˺
+    HSAccountID                   AccountID;
+    /// 
+    HSPassword                    Password;
+    /// ͻid
+    HSAppID                       AppID;
+    /// ֤
+    HSAuthCode                    AuthCode;
 };
 
 ///֤Ӧ
 struct CHSRspAuthenticateField
 {
-	/// ˺
-	HSAccountID                   AccountID;
-	HSAppID                       AppID;
-	HSAuthCode                    AuthCode;
+    /// ˺
+    HSAccountID                   AccountID;
+    /// ͻID
+    HSAppID                       AppID;
+    /// ֤
+    HSAuthCode                    AuthCode;
+    /// ͻID
+    HSAppIDType                   AppIDType;
+};
+
+
+///ûϢϱ
+struct CHSReqUserSystemInfoField
+{
+    /// ͻ˵½ʱ
+    HSStrTime                    AppLoginTime;
+    /// ͻ˹ַ
+    HSIPAddress                  AppPublicAdrr;
+    /// ͻϵͳϢ
+    HSAppSysInfo                 AppSysInfo;
+    /// ͻϵͳϢɼ
+    HSAppSysInfoIntegrity        AppSysInfoIntegrity;
+    /// ͻϵͳϢɼ쳣ʶ
+    HSAppAbnormalType            AppAbnormalType;
+};
+
+///ûϢϱӦ
+struct CHSRspUserSystemInfoField
+{
 };
 
 ///ͻ¼
@@ -60,6 +85,8 @@ struct CHSReqUserLoginField
     HSMacAddress                  MacAddress;
     /// ͶIPַ
     HSIPAddress                   IPAddress;
+    /// ͶվϢ
+    HSUserStationInfo             UserStationInfo;
 };
 ///ͻ¼Ӧ
 struct CHSRspUserLoginField
@@ -100,6 +127,10 @@ struct CHSRspUserLoginField
     HSTime                        CFFEXTime;
     /// Դĵǰʱ
     HSTime                        INETime;
+    /// 󱨵(ػỰϴ󱨵)
+    HSRef                         MaxOrderRef;
+    /// ͻ
+    HSUserID                      UserID;
 };
 
 ///
@@ -144,6 +175,8 @@ struct CHSReqOrderInsertField
     HSPrice                       SpringPrice;
     /// ־
     HSSwapOrderFlag               SwapOrderFlag;
+    /// ϳֱֲ
+    HSCombPositionID              CombPositionID;
 };
 ///¼Ӧ
 struct CHSRspOrderInsertField
@@ -184,6 +217,8 @@ struct CHSRspOrderInsertField
     HSPrice                       SpringPrice;
     /// ־
     HSSwapOrderFlag               SwapOrderFlag;
+    /// ϳֱֲ
+    HSCombPositionID              CombPositionID;
 };
 
 ///
@@ -236,6 +271,10 @@ struct CHSReqExerciseOrderInsertField
     HSExerciseType                ExerciseType;
     /// Ͷ/ױ/
     HSHedgeType                   HedgeType;
+    /// ƽ־
+    HSOffsetFlag                  OffsetFlag;
+    /// ȨȨɵͷǷԶƽ
+    HSCloseFlag                   CloseFlag;
 };
 ///Ȩ¼Ӧ
 struct CHSRspExerciseOrderInsertField
@@ -262,6 +301,10 @@ struct CHSRspExerciseOrderInsertField
     HSOrderStatus                 OrderStatus;
     /// ʱ
     HSTime                        InsertTime;
+    /// ƽ־
+    HSOffsetFlag                  OffsetFlag;
+    /// ȨȨɵͷǷԶƽ
+    HSCloseFlag                   CloseFlag;
 };
 
 ///Ȩ
@@ -419,6 +462,8 @@ struct CHSReqQueryMaxOrderVolumeField
     HSHedgeType                   HedgeType;
     /// ۸
     HSPrice                       OrderPrice;
+    /// ϳֱֲ
+    HSCombPositionID              CombPositionID;
 };
 ///󱨵ȡӦ
 struct CHSRspQueryMaxOrderVolumeField
@@ -443,10 +488,12 @@ struct CHSRspQueryMaxOrderVolumeField
     HSHedgeType                   HedgeType;
     /// ۸
     HSPrice                       OrderPrice;
+    /// ϳֱֲ
+    HSCombPositionID              CombPositionID;
 };
 
 ///ȡ
-struct CHSReqQueryLockVolumeField
+struct CHSReqQryLockVolumeField
 {
     /// 
     HSExchangeID                  ExchangeID;
@@ -456,7 +503,7 @@ struct CHSReqQueryLockVolumeField
     HSLockType                    LockType;
 };
 ///ȡӦ
-struct CHSRspQueryLockVolumeField
+struct CHSRspQryLockVolumeField
 {
     /// ˺
     HSAccountID                   AccountID;
@@ -491,6 +538,39 @@ struct CHSRspQueryExerciseVolumeField
     HSInstrumentID                InstrumentID;
 };
 
+///ȡ
+struct CHSReqQryCombVolumeField
+{
+    /// 
+    HSExchangeID                  ExchangeID;
+    /// Լ
+    HSInstrumentID                InstrumentID;
+    /// ϲԱ
+    HSCombStrategyID              CombStrategyID;
+    /// ϳֱֲ
+    HSCombPositionID              CombPositionID;
+    /// ָ
+    HSCombDirection               CombDirection;
+};
+///ȡӦ
+struct CHSRspQryCombVolumeField
+{
+    /// ˺
+    HSAccountID                   AccountID;
+    /// 
+    HSExchangeID                  ExchangeID;
+    /// Լ
+    HSInstrumentID                InstrumentID;
+    /// ϲԱ
+    HSCombStrategyID              CombStrategyID;
+    /// ϳֱֲ
+    HSCombPositionID              CombPositionID;
+    /// ָ
+    HSCombDirection               CombDirection;
+    /// 󱨵
+    HSVolume                      MaxOrderVolumeUnit;
+};
+
 ///ֲֻܲѯ
 struct CHSReqQryPositionField
 {
@@ -629,6 +709,8 @@ struct CHSRspQryTradingAccountField
     HSBalance                     UnFrozenBalance;
     /// 
     HSCurrencyID                  CurrencyID;
+    /// Գն
+    HSRiskDegree                  HedgeRiskDegree;
 };
 
 ///ѯ
@@ -641,6 +723,22 @@ struct CHSReqQryOrderField
     /// 
     HSOrderSysID                  OrderSysID;
 };
+
+///ʷѯ
+struct CHSReqQryHistOrderField
+{
+    /// 
+    HSExchangeID                   ExchangeID;
+    /// Լ
+    HSInstrumentID                 InstrumentID;
+    /// 
+    HSOrderSysID                   OrderSysID;
+    /// ʼ
+    HSDate                         BeginDate;
+    /// 
+    HSDate                         EndDate;
+};
+
 ///Ϣ
 struct CHSOrderField
 {
@@ -700,6 +798,8 @@ struct CHSOrderField
     HSInstrumentID                UnderlyingInstrID;
     /// 
     HSOrderSource                 OrderSource;
+    /// ϳֱֲ
+    HSCombPositionID              CombPositionID;
 };
 
 ///ɽѯ
@@ -710,6 +810,20 @@ struct CHSReqQryTradeField
     /// Լ
     HSInstrumentID                InstrumentID;
 };
+
+///ʷɽѯ
+struct CHSReqQryHistTradeField
+{
+    /// 
+    HSExchangeID                   ExchangeID;
+    /// Լ
+    HSInstrumentID                 InstrumentID;
+    /// ʼ
+    HSDate                         BeginDate;
+    /// 
+    HSDate                         EndDate;
+};
+
 ///ɽϢ
 struct CHSTradeField
 {
@@ -745,6 +859,10 @@ struct CHSTradeField
     HSTime                        TradeTime;
     /// ȨӦıĺԼ
     HSInstrumentID                UnderlyingInstrID;
+    /// ϳֱֲ
+    HSCombPositionID              CombPositionID;
+    /// ɽ
+    HSBalance                     TradeCommission;
 };
 
 ///Ȩѯ
@@ -757,6 +875,22 @@ struct CHSReqQryExerciseField
     /// Ȩ
     HSOrderSysID                  ExerciseOrderSysID;
 };
+
+///ʷȨѯ
+struct CHSReqQryHistExerciseField
+{
+    /// 
+    HSExchangeID                  ExchangeID;
+    /// Լ
+    HSInstrumentID                InstrumentID;
+    /// Ȩ
+    HSOrderSysID                  ExerciseOrderSysID;
+    /// ʼ
+    HSDate                        BeginDate;
+    /// 
+    HSDate                        EndDate;
+};
+
 ///ȨϢ
 struct CHSExerciseField
 {
@@ -794,6 +928,10 @@ struct CHSExerciseField
     HSCloseFlag                   CloseFlag;
     /// ƽ־
     HSOffsetFlag                  OffsetFlag;
+    /// ȨԤ
+    HSBalance                     ExercisePreFrozenCommission;
+    /// ȨԤᱣ֤
+    HSBalance                     ExercisePreFrozenMargin;
 };
 
 ///ѯ
@@ -806,6 +944,22 @@ struct CHSReqQryLockField
     /// 
     HSOrderSysID                  LockOrderSysID;
 };
+
+///ʷѯ
+struct CHSReqQryHistLockField
+{
+    /// 
+    HSExchangeID                  ExchangeID;
+    /// ȨӦıĺԼ
+    HSInstrumentID                UnderlyingInstrID;
+    /// 
+    HSOrderSysID                  LockOrderSysID;
+    /// ʼ
+    HSDate                        BeginDate;
+    /// 
+    HSDate                        EndDate;
+};
+
 ///Ϣ
 struct CHSLockField
 {
@@ -843,6 +997,22 @@ struct CHSReqQryCombActionField
     /// Լ
     HSInstrumentID                InstrumentID;
 };
+
+///ʷϲѯ
+struct CHSReqQryHistCombActionField
+{
+    /// ϱ
+    HSOrderSysID                  CombOrderSysID;
+    /// 
+    HSExchangeID                  ExchangeID;
+    /// Լ
+    HSInstrumentID                InstrumentID;
+    /// ʼ
+    HSDate                        BeginDate;
+    /// 
+    HSDate                        EndDate;
+};
+
 ///Ϣ
 struct CHSCombActionField
 {
@@ -998,7 +1168,7 @@ struct CHSRspQryCoveredShortField
     /// Ԥȱ
     HSVolume                      CoveredEstimateShortVolume;
     /// Ϣ
-    HSMsgContent                   MsgContent;
+    HSMsgContent                  MsgContent;
 };
 
 ///Ȩָɲѯ
@@ -1154,6 +1324,33 @@ struct CHSRspQueryBankAccountField
     HSCurrencyID                  CurrencyID;
 };
 
+///ʽ
+struct CHSReqMultiCentreFundTransField
+{
+    /// 
+    HSCurrencyID                  CurrencyID;
+    /// 
+    HSBalance                     OccurBalance;
+    /// 
+    HSTransDirection              TransDirection;
+};
+///ʽӦ
+struct CHSRspMultiCentreFundTransField
+{
+    /// ˺
+    HSAccountID                   AccountID;
+    /// 
+    HSCurrencyID                  CurrencyID;
+    /// 
+    HSBalance                     OccurBalance;
+    /// 
+    HSTransDirection              TransDirection;
+    /// ʽˮ
+    HSNum                         LocalTransferSerialID;
+    /// Զʽˮ
+    HSNum                         OppositeTransferSerialID;
+};
+
 ///ͻ˵ѯ
 struct CHSReqQueryBillContentField
 {
@@ -1283,22 +1480,22 @@ struct CHSRspQryCommissionField
 ///ʲѯ
 struct CHSReqQryExchangeRateField
 {
-	/// ԭ
-	HSCurrencyID                  FromCurrencyID;
-	/// Ŀ
-	HSCurrencyID                  ToCurrencyID;
+    /// ԭ
+    HSCurrencyID                  FromCurrencyID;
+    /// Ŀ
+    HSCurrencyID                  ToCurrencyID;
 };
 ///ʲѯӦ
 struct CHSRspQryExchangeRateField
 {
-	/// ԭ
-	HSCurrencyID                  FromCurrencyID;
-	/// Ŀ
-	HSCurrencyID                  ToCurrencyID;
-	/// 
-	HSExchangeRate                ExchangeRate;
-	/// ԭλ
-	HSVolume                      FromCurrencyUnit;
+    /// ԭ
+    HSCurrencyID                  FromCurrencyID;
+    /// Ŀ
+    HSCurrencyID                  ToCurrencyID;
+    /// 
+    HSExchangeRate                ExchangeRate;
+    /// ԭλ
+    HSVolume                      FromCurrencyUnit;
 };
 
 ///ֲϸѯ
@@ -1367,10 +1564,10 @@ struct CHSReqDepthMarketDataField
 ///ѯ
 struct CHSReqQryDepthMarketDataField
 {
-	/// 
-	HSExchangeID                  ExchangeID;
-	/// Լ
-	HSInstrumentID                InstrumentID;
+    /// 
+    HSExchangeID                  ExchangeID;
+    /// Լ
+    HSInstrumentID                InstrumentID;
 };
 
 ///Ϣ
@@ -1464,6 +1661,252 @@ struct CHSDepthMarketDataField
     HSOpenRestriction             OpenRestriction;
 };
 
+///Ϣ
+struct CHSOrderActionField
+{
+    /// ˺
+    HSAccountID                   AccountID;
+    /// 
+    HSOrderSysID                  OrderSysID;
+    /// ͹˾
+    HSBrokerOrderID               BrokerOrderID;
+    /// Ự
+    HSSessionID                   SessionID;
+    /// 
+    HSRef                         OrderRef;
+    /// 
+    HSRef                         OrderActionRef;
+    /// 
+    HSExchangeID                  ExchangeID;
+    /// Լ
+    HSInstrumentID                InstrumentID;
+    /// 
+    HSDirection                   Direction;
+    /// ƽ־
+    HSOffsetFlag                  OffsetFlag;
+    /// Ͷ/ױ/
+    HSHedgeType                   HedgeType;
+    /// ۸
+    HSPrice                       OrderPrice;
+    /// 
+    HSVolume                      OrderVolume;
+    /// ״̬
+    HSOrderStatus                 OrderActionStatus;
+    /// ״̬
+    HSOrderStatus                 OrderStatus;
+    /// 
+    HSDate                        TradingDay;
+    /// 
+    HSDate                        ActionDate;
+    /// ʱ
+    HSTime                        ActionTime;
+    /// Ϣ
+    HSErrorMsg                    ErrorMsg;
+    /// ȨӦıĺԼ
+    HSInstrumentID                UnderlyingInstrID;
+    /// 
+    HSOrderSource                 OrderSource;
+};
+
+///ٽ뼯н֮ʽ
+struct CHSReqFundTransField
+{
+    /// 
+    HSTransDirection              TransDirection;
+    /// 
+    HSCurrencyID                  CurrencyID;
+    /// 
+    HSBalance                     OccurBalance;
+};
+
+///ٽ뼯н֮ʽӦ
+struct CHSRspFundTransField
+{
+    /// ʽˮ
+    HSNum                         FundTransSerialID;
+};
+
+///ʽˮѯ
+struct CHSReqQryFundTransField
+{
+
+};
+
+///ʽˮѯӦ
+struct CHSRspQryFundTransField
+{
+    /// ˺
+    HSAccountID                   AccountID;
+    /// 
+    HSDate                        TradingDay;
+    /// 
+    HSDate                        OccurDate;
+    /// ʱ
+    HSTime                        OccurTime;
+    /// תˮ
+    HSNum                         TransferSerialID;
+    /// 
+    HSCurrencyID                  CurrencyID;
+    /// 
+    HSBalance                     OccurBalance;
+    /// ʽ
+    HSBalance                     PostBalance;
+};
+
+///ͻ֪ͨѯ
+struct CHSReqQryClientNoticeField
+{
+
+};
+
+///ͻ֪ͨϢ
+struct CHSClientNoticeField
+{
+    /// ˺
+    HSAccountID                   AccountID;
+    /// Ϣ
+    HSMsgBody                     MsgContent;
+    /// Ϣ
+    HSMsgTitle                    MsgTitle;
+    /// Ϣ
+    HSMsgType                     MsgType;
+    /// Ϣ
+    HSDate                        MsgDate;
+    /// Ϣʱ
+    HSTime                        MsgTime;
+};
+
+///ȨϢѯ
+struct CHSReqQryOptUnderlyField
+{
+    /// 
+    HSExchangeID                   ExchangeID;
+    /// ȨӦıĺԼ
+    HSInstrumentID                 UnderlyingInstrID;
+};
+
+///ȨϢѯӦ
+struct CHSRspQryOptUnderlyField
+{
+    /// 
+    HSExchangeID                   ExchangeID;
+    /// ȨӦıĺԼ
+    HSInstrumentID                 UnderlyingInstrID;
+    /// ȨӦ
+    HSStockType                    UnderlyingType;
+    /// 
+    HSCurrencyID                   CurrencyID;
+    /// ȨӦ״̬
+    HSStatus                       UnderlyingStatus;
+    /// ͣ
+    HSPrice                        UpperLimitPrice;
+    /// ͣ
+    HSPrice                        LowerLimitPrice;
+    /// ȨӦĽ
+    HSVolume                       UnderlyingHighAmount;
+    /// ȨӦĽ
+    HSVolume                       UnderlyingLowAmount;
+    /// Լ
+    HSVolume                       VolumeMultiple;
+    /// 뵥λ
+    HSNum                          BuyUnit;
+    /// λ
+    HSNum                          SellUnit;
+    /// С۲()
+    HSNum                          PriceStep;
+    /// 
+    HSDate                         MarketDate;
+    /// 
+    HSDate                         DelistDate;
+    /// ȨӦм۽
+    HSVolume                       UnderlyingMarketHighAmount;
+    /// ȨӦм۽
+    HSVolume                       UnderlyingMarketLowAmount;
+    /// 
+    HSInstrumentName               UnderlyingName;
+    /// м뵥λ
+    HSNum                          MarketBuyUnit;
+    /// мλ
+    HSNum                          MarketSellUnit;
+    /// ȨӦЧ
+    HSDate                         UnderlyingValidDate;
+    /// 
+    HSNum                          UpdateType;
+};
+
+///֤ȯѯ
+struct CHSReqQrySecuDepthMarketField
+{
+    /// 
+    HSExchangeID                   ExchangeID;
+    /// ȨӦıĺԼ
+    HSInstrumentID                 UnderlyingInstrID;
+};
+
+///֤ȯѯӦ
+struct CHSRspQrySecuDepthMarketField
+{
+    /// 
+    HSExchangeID                   ExchangeID;
+    /// ȨӦıĺԼ
+    HSInstrumentID                 UnderlyingInstrID;
+    /// 
+    HSInstrumentName               UnderlyingName;
+    /// ¼
+    HSPrice                        LastPrice;
+    /// ̼
+    HSPrice                        OpenPrice;
+    /// ̼
+    HSPrice                        UnderlyingPreClosePrice;
+    /// ߼
+    HSPrice                        HighestPrice;
+    /// ͼ
+    HSPrice                        LowestPrice;
+    /// ɽ
+    HSBalance                      TradeBalance;
+    /// ɽ
+    HSVolume                       TradeVolume;
+    /// һ
+    HSPrice                        BidPrice1;
+    /// һ
+    HSVolume                       BidVolume1;
+    /// һ
+    HSPrice                        AskPrice1;
+    /// һ
+    HSVolume                       AskVolume1;
+    /// ۶
+    HSPrice                        BidPrice2;
+    /// 
+    HSVolume                       BidVolume2;
+    /// ۶
+    HSPrice                        AskPrice2;
+    /// 
+    HSVolume                       AskVolume2;
+    /// 
+    HSPrice                        BidPrice3;
+    /// 
+    HSVolume                       BidVolume3;
+    /// 
+    HSPrice                        AskPrice3;
+    /// 
+    HSVolume                       AskVolume3;
+    /// 
+    HSPrice                        BidPrice4;
+    /// 
+    HSVolume                       BidVolume4;
+    /// 
+    HSPrice                        AskPrice4;
+    /// 
+    HSVolume                       AskVolume4;
+    /// 
+    HSPrice                        BidPrice5;
+    /// 
+    HSVolume                       BidVolume5;
+    /// 
+    HSPrice                        AskPrice5;
+    /// 
+    HSVolume                       AskVolume5;
+};
 
 #pragma pack(pop)
 #endif
